@@ -1,10 +1,16 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 
 from flask import request, jsonify, Response, abort
 
+import simplejson
+
+# TODO: remove for Python 3.7+
+import flask
+flask.json = simplejson
+
 import base64
 import uuid
 import logging
